/**
 * File main.js.
 */

( function ( $ ) {
	$( document ).ready( function () {

		// The Bootstrap 4 Comment Form validation.
		( function () {
			'use strict';
			window.addEventListener( 'load', function () {
				// Fetch all the forms we want to apply custom Bootstrap validation styles to
				var forms = document.getElementsByClassName( 'comment-form' );
				// Loop over them and prevent submission
				var validation = Array.prototype.filter.call( forms, function ( form ) {
					form.addEventListener( 'submit', function ( event ) {
						if ( form.checkValidity() === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
						form.classList.add( 'was-validated' );
					}, false );
				} );
			}, false );
		} )();

		// External Link Notification.
		$( 'a' ).not( '.ya-share2__link' ).filter( function () {
			return this.hostname && this.hostname !== location.hostname;
		} ).click( function () {
			return window.confirm( 'Вы действительно хотите перейти по внешней ссылке?\nМы не несём ответственности за содержимое на ' + this.hostname );
		} );

		// Bootstrap Tooltip.
		if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
			$( '[data-toggle="tooltip"]' ).tooltip();
		}

		// Initialize Fancybox 3.
		if ( $.fancybox ) {
			$( '.single-articles a.fancybox' ).fancybox();
		}

		// Smooth scrolling when clicking an anchor link.
		$( document ).on( 'click', 'a[href^="#"]:not([href="#"])', function ( a ) {
			a.preventDefault();

			$( 'html, body' ).animate( {
				scrollTop: $( $.attr( this, 'href' ) ).offset().top,
			}, 300 );
		} );

		// Hide/open sidebar max list items.
		$( function () {
			let depList       = '#dependencies-list';
			let depListFooter = '#dependencies-list-footer';
			let depListCount  = $( depList + ' li' ).length;
			let depListMax    = depList + ' li:gt(12)';

			if ( depListCount > 14 ) {
				$( depListMax ).not( depListFooter ).hide();
				$( depListFooter ).removeClass( 'd-none' );
				$( depListFooter + ' > button' ).click( function () {
					$( depListMax ).slideDown();
					$( depListFooter ).addClass( 'd-none' );
				} );
			}
		} );

		// Escaping the regular expression.
		function escapeRegExp( string ) {
			return string.replace( /[.*+?^${}()|[\]\\]/g, '\\$&' );
		}

		// AJAX Search.
		$( 'form.search-form.search-helper' ).each( function () {
			$( this ).find( 'input' ).autocomplete( {
				appendTo: $( this ),
				source: function ( request, response ) {
					let allowedSymbols = new RegExp( '^[a-z0-9+-.]+$', 'i' );

					if ( -1 !== request.term.indexOf( ' ' ) || !allowedSymbols.test( request.term ) ) {
						response( [] );
						return false;
					}
					$.ajax( {
						url: os_ajax.ajax_url,
						type: 'POST',
						dataType: 'json',
						data: {
							action: 'search',
							request: request.term,
							nonce_code: os_ajax.ajax_nonce,
						},
						success: function ( data ) {
							response( data.data );
						},
					} );
				},
				create: function ( event, ui ) {
					$( this ).data( 'ui-autocomplete' ).menu.element.addClass( 'position-absolute list-group' );
					$( this ).data( 'ui-autocomplete' )._renderItem = function ( ul, item ) {
						let searchMatch = new RegExp( escapeRegExp( this.term ), 'gi' );
						let newText     = String( item.value ).replace( searchMatch, '<span class="ui-state-highlight">$&</span>' );

						return $( '<li>' ).append( newText ).appendTo( ul );
					};
				},
				open: function ( event, ui ) {
					$( this ).data( 'ui-autocomplete' ).menu.element.addClass( 'd-flex' );
					$( this ).data( 'ui-autocomplete' ).menu.element.find( 'li' ).addClass( 'list-group-item px-3 py-1' );
				},
				close: function ( event, ui ) {
					$( this ).data( 'ui-autocomplete' ).menu.element.removeClass( 'd-flex' );
				},
				select: function ( event, ui ) {
					if ( ui.item ) {
						$( event.target ).val( ui.item.value );
						$( event.target.form ).submit();
					}
				},
				minLength: 2,
				messages: {
					noResults: '',
					results: function () {
					},
				},
			} ).focus( function () {
				$( this ).autocomplete( 'search' );
			} );
		} );
		$( '.ui-helper-hidden-accessible' ).remove();
		$( window ).resize( function () {
			$( '.search-helper input' ).autocomplete( 'close' );
		} );
		$( 'form.search-form .search-reset' ).on( 'click', function () {
			$( this ).closest( '.input-group' ).find( 'input.search-field' ).val( '' ).focus();
		} );

		// Copy to clipboard.
		$( '.package-install-copy' ).on( 'click', function () {
			let copyText = $( this ).siblings( '.package-install' ).text();

			window.navigator.clipboard.writeText( copyText );

			if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
				$( this ).tooltip( 'hide' ).tooltip( 'show' ).mouseleave( function () {
					$( this ).tooltip( 'hide' );
				} );
			}
		} );

		// Fade scroll top.
		$( '#arrow-up' ).hide();
		$( window ).scroll( function () {
			let y = $( this ).scrollTop();

			if ( y > 300 ) {
				$( '#arrow-up' ).fadeIn().css( 'display', 'flex' );
			} else {
				$( '#arrow-up' ).fadeOut();
			}
		} );

		// Prettify.
		if ( window.prettyPrint ) {
			prettyPrint();
		}

		let codeTarget = 'pre[class*="language-"]';

		// Set <pre> wrapper.
		$( codeTarget ).wrap( '<div class="code-pre-wrap"></div>' );

		// Add a Prism themes button.
		$( function () {
			let markup = '<span class="dashicons dashicons-admin-generic text-secondary prism-theme" data-toggle="tooltip" title="Тёмная тема"></span>';
			let button = $( '.code-pre-wrap' ).append( markup ).children( '.prism-theme' );

			function changeTitle( current ) {
				let title = ( $( '#primary' ).hasClass( 'prism-theme-light' ) ) ? 'Тёмная тема' : 'Светлая тема';

				current.tooltip( 'dispose' ).attr( 'title', title ).tooltip( 'show' );
			}

			if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
				button.on( 'mouseenter', function () {
					changeTitle( $( this ) );
				} );
			}

			button.on( 'click', function () {
				$( '#primary' ).toggleClass( 'prism-theme-light prism-theme-dark' );

				if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
					changeTitle( $( this ) );
				}
			} );
		} );

		// Add a Clipboard button.
		$( function () {
			let markup = '<span class="dashicons dashicons-admin-page text-secondary code-clipboard" data-toggle="tooltip" title="Скопировать"></span>';
			let button = $( '.code-pre-wrap' ).append( markup ).children( '.code-clipboard' );

			function changeTitle( current, title ) {
				current.tooltip( 'dispose' ).attr( 'title', title ).tooltip( 'show' );
			}

			if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
				button.on( 'mouseenter', function () {
					changeTitle( $( this ), 'Скопировать' );
				} );
			}

			button.on( 'click', function () {
				let copyText = $( this ).siblings( codeTarget ).text();

				window.navigator.clipboard.writeText( copyText );

				if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
					changeTitle( $( this ), 'Готово!' );
				}
			} );
		} );

		// AJAX comment votes.
		$( function () {
			let comment = '#comments article.comment-body';
			let html;

			html  = '<div class="comment-votes btn-group" role="group" aria-label="Comment votes">';
			html += '<button type="button" class="btn shadow-none p-0"><span class="dashicons dashicons-thumbs-up"></span></button>';
			html += '<span class="btn disabled p-0 px-1"><span class="badge text-secondary bg-transparent">0</span></span>';
			html += '<button type="button" class="btn shadow-none p-0"><span class="dashicons dashicons-thumbs-down"></span></button>';
			html += '</div>';

			$( html ).appendTo( comment );

			// AJAX votes by onload.
			$.ajax( {
				url: os_ajax.ajax_url,
				type: 'POST',
				dataType: 'json',
				data: {
					action: 'comment_votes',
					event: 'onload',
					nonce_code: os_ajax.ajax_nonce,
				},
				success: function ( response ) {
					$( comment ).each( function () {
						let id    = $( this ).attr( 'id' ).split( '-' ).pop();
						let count = response.data[ id ];

						if ( 'undefined' !== typeof( count ) ) {
							$( this ).find( '.badge' ).text( count );
						}
					} );
				},
			} );

			$( comment ).find( 'button.btn' ).one( 'click', function () {
				let btn     = this;
				let badge   = $( this ).siblings( 'span' ).find( '.badge' );
				let id      = $( this ).closest( comment ).attr( 'id' ).split( '-' ).pop();
				let status  = 'like';

				function votedTip() {
					$( badge ).tooltip( {
						title: 'Оценка уже сделана!',
					} ).tooltip( 'show' );

					$( btn ).on( 'mouseleave', function () {
						$( badge ).tooltip( 'dispose' );
					} );
				}

				if ( $( this ).find( '.dashicons' ).hasClass( 'dashicons-thumbs-down' ) ) {
					status = 'dislike';
				}

				// AJAX votes by click.
				$.ajax( {
					url: os_ajax.ajax_url,
					type: 'POST',
					dataType: 'json',
					data: {
						action: 'comment_votes',
						event: 'click',
						id: id,
						status: status,
						nonce_code: os_ajax.ajax_nonce,
					},
					success: function ( response ) {
						if ( 'undefined' !== typeof( response.data ) ) {
							badge.text( response.data );
						} else {
							if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
								votedTip();
							}
						}
					},
				} );

				if ( ! $( 'body' ).hasClass( 'os-mobile' ) ) {
					$( this ).on( 'click', function () {
						votedTip();
					} );
				}
			} );

			// AJAX cookie notice.
			$( function () {
				if ( ! document.cookie.split( ';' ).filter( ( item ) => item.trim().startsWith( 'os_cookie_notice=' ) ).length ) {
					$( '#cookie-notice' ).toast( 'show' );
				}

				$( '#cookie-notice .close' ).one( 'click', function () {
					$.ajax( {
						url: os_ajax.ajax_url,
						type: 'POST',
						dataType: 'json',
						data: {
							action: 'cookie_notice',
							nonce_code: os_ajax.ajax_nonce,
						}
					} );
				} );
			} );

			// Table of Contents.
			if ( 'undefined' !== typeof toc ) {
				$( '#toc' ).toc( {
					content: 'body.articles-template-default .article-body',
					headings: 'h2,h3,h4',
					numeric: true,
					excluded: 'Содержание',
				} );
			}
			// Table of Contents hide-button.
			( function () {
				let toc = '#toc, ul[data-toc]';
				let btn = '#toc-btn';

				$( '<button id="toc-btn" class="d-block btn btn-sm btn-outline-secondary font-weight-light border-0 ml-auto mb-2 py-0">Скрыть</button>' ).insertBefore( $( toc ) );

				$( btn ).on( 'click', function () {
					$( toc ).slideToggle( 'fast', function() {
						if ( 'Скрыть' === $( btn ).text() ) {
							$( btn ).text( 'Показать' );
						} else {
							$( btn ).text( 'Скрыть' );
						}
					} );
				} );
			} )();
		} );
	} );
} )( jQuery );
